/*
  Button

  Turns on and off a light emitting diode(LED) connected to digital pin 4,
  when pressing a pushbutton attached to pin 3.

  The circuit:
  - OLED Interface pin 1 is GND (Black wire)
  - OLED Interface pin 2 is +3.3V (Red Wire)
  - OLED Interface pin 3 is SCL is connected to the SIG connection on the button (Yellow Wire)
  - OLED Interface pin 4 is not connected (NC) on the Grove button
  - LED attached from pin 3 to ground through 1 Kohm resistor on ATTiny412 OLED dev board
  - Input device is a momentary normally open pushbutton from Grove Beginner Kit attached to pin 4 on ATTiny412 OLED dev board


  - Note: on most Arduinos there is already an LED on the board
    attached to pin 13. However, this is an ATTiny412 OLED dev board with a SMD Red LED.

  created 2005
  by DojoDave <http://www.0j0.org>
  modified 30 Aug 2011
  by Tom Igoe
  modified 18 Apr 2023
  by Jim Hart For Tiny412: ledPin to pin 4, buttonPin to pin 3  

  This example code is in the public domain.

  https://www.arduino.cc/en/Tutorial/BuiltInExamples/Button
*/

// constants won't change. They're used here to set pin numbers:
const int buttonPin = 3;     // the number of the pushbutton pin
const int ledPin =  4;      // the number of the LED pin

// variables will change:
int buttonState = 0;         // variable for reading the pushbutton status

void setup() {
  // initialize the LED pin as an output:
  pinMode(ledPin, OUTPUT);
  // initialize the pushbutton pin as an input:
  pinMode(buttonPin, INPUT);
}

void loop() {
  // read the state of the pushbutton value:
  buttonState = digitalRead(buttonPin);

  // check if the pushbutton is pressed. If it is, the buttonState is HIGH:
  if (buttonState == HIGH) {
    // turn LED on:
    digitalWrite(ledPin, HIGH);
  } else {
    // turn LED off:
    digitalWrite(ledPin, LOW);
  }
}
